"""
    VRChat API Documentation


    The version of the OpenAPI document: 1.7.3
    Contact: me@ariesclark.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from vrchatapi.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)
from ..model_utils import OpenApiModel
from vrchatapi.exceptions import ApiAttributeError


def lazy_import():
    from vrchatapi.model.api_event_config import APIEventConfig
    from vrchatapi.model.avatar_id import AvatarID
    from vrchatapi.model.deployment_group import DeploymentGroup
    from vrchatapi.model.download_url_list import DownloadURLList
    from vrchatapi.model.dynamic_content_row import DynamicContentRow
    from vrchatapi.model.public_announcement import PublicAnnouncement
    from vrchatapi.model.world_id import WorldID
    globals()['APIEventConfig'] = APIEventConfig
    globals()['AvatarID'] = AvatarID
    globals()['DeploymentGroup'] = DeploymentGroup
    globals()['DownloadURLList'] = DownloadURLList
    globals()['DynamicContentRow'] = DynamicContentRow
    globals()['PublicAnnouncement'] = PublicAnnouncement
    globals()['WorldID'] = WorldID


class APIConfig(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
        ('address',): {
            'min_length': 1,
        },
        ('announcements',): {
            'min_items': 1,
        },
        ('api_key',): {
            'min_length': 1,
        },
        ('app_name',): {
            'min_length': 1,
        },
        ('build_version_tag',): {
            'min_length': 1,
        },
        ('client_api_key',): {
            'min_length': 1,
        },
        ('contact_email',): {
            'min_length': 1,
        },
        ('copyright_email',): {
            'min_length': 1,
        },
        ('current_tos_version',): {
            'inclusive_minimum': 0,
        },
        ('dev_app_version_standalone',): {
            'min_length': 1,
        },
        ('dev_download_link_windows',): {
            'min_length': 1,
        },
        ('dev_sdk_url',): {
            'min_length': 1,
        },
        ('dev_sdk_version',): {
            'min_length': 1,
        },
        ('dev_server_version_standalone',): {
            'min_length': 1,
        },
        ('download_link_windows',): {
            'min_length': 1,
        },
        ('dynamic_world_rows',): {
            'min_items': 1,
        },
        ('gear_demo_room_id',): {
            'min_length': 1,
        },
        ('homepage_redirect_target',): {
            'min_length': 1,
        },
        ('jobs_email',): {
            'min_length': 1,
        },
        ('message_of_the_day',): {
            'min_length': 1,
        },
        ('moderation_email',): {
            'min_length': 1,
        },
        ('not_allowed_to_select_avatar_in_private_world_message',): {
            'min_length': 1,
        },
        ('plugin',): {
            'min_length': 1,
        },
        ('release_app_version_standalone',): {
            'min_length': 1,
        },
        ('release_sdk_url',): {
            'min_length': 1,
        },
        ('release_sdk_version',): {
            'min_length': 1,
        },
        ('release_server_version_standalone',): {
            'min_length': 1,
        },
        ('sdk_developer_faq_url',): {
            'min_length': 1,
        },
        ('sdk_discord_url',): {
            'min_length': 1,
        },
        ('sdk_not_allowed_to_publish_message',): {
            'min_length': 1,
        },
        ('sdk_unity_version',): {
            'min_length': 1,
        },
        ('server_name',): {
            'min_length': 1,
        },
        ('support_email',): {
            'min_length': 1,
        },
        ('vive_windows_url',): {
            'min_length': 1,
        },
        ('player_url_resolver_hash',): {
            'min_length': 1,
        },
        ('player_url_resolver_version',): {
            'min_length': 1,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'voice_enable_degradation': (bool,),  # noqa: E501
            'voice_enable_receiver_limiting': (bool,),  # noqa: E501
            'address': (str,),  # noqa: E501
            'announcements': ([PublicAnnouncement],),  # noqa: E501
            'api_key': (str,),  # noqa: E501
            'app_name': (str,),  # noqa: E501
            'build_version_tag': (str,),  # noqa: E501
            'client_api_key': (str,),  # noqa: E501
            'client_bps_ceiling': (int,),  # noqa: E501
            'client_disconnect_timeout': (int,),  # noqa: E501
            'client_reserved_player_bps': (int,),  # noqa: E501
            'client_sent_count_allowance': (int,),  # noqa: E501
            'contact_email': (str,),  # noqa: E501
            'copyright_email': (str,),  # noqa: E501
            'current_tos_version': (int,),  # noqa: E501
            'default_avatar': (AvatarID,),  # noqa: E501
            'deployment_group': (DeploymentGroup,),  # noqa: E501
            'dev_app_version_standalone': (str,),  # noqa: E501
            'dev_download_link_windows': (str,),  # noqa: E501
            'dev_sdk_url': (str,),  # noqa: E501
            'dev_sdk_version': (str,),  # noqa: E501
            'dev_server_version_standalone': (str,),  # noqa: E501
            'dis_countdown': (datetime,),  # noqa: E501
            'disable_avatar_copying': (bool,),  # noqa: E501
            'disable_avatar_gating': (bool,),  # noqa: E501
            'disable_community_labs': (bool,),  # noqa: E501
            'disable_community_labs_promotion': (bool,),  # noqa: E501
            'disable_email': (bool,),  # noqa: E501
            'disable_event_stream': (bool,),  # noqa: E501
            'disable_feedback_gating': (bool,),  # noqa: E501
            'disable_frontend_builds': (bool,),  # noqa: E501
            'disable_hello': (bool,),  # noqa: E501
            'disable_oculus_subs': (bool,),  # noqa: E501
            'disable_registration': (bool,),  # noqa: E501
            'disable_steam_networking': (bool,),  # noqa: E501
            'disable_two_factor_auth': (bool,),  # noqa: E501
            'disable_udon': (bool,),  # noqa: E501
            'disable_upgrade_account': (bool,),  # noqa: E501
            'download_link_windows': (str,),  # noqa: E501
            'download_urls': (DownloadURLList,),  # noqa: E501
            'dynamic_world_rows': ([DynamicContentRow],),  # noqa: E501
            'events': (APIEventConfig,),  # noqa: E501
            'gear_demo_room_id': (str,),  # noqa: E501
            'home_world_id': (WorldID,),  # noqa: E501
            'homepage_redirect_target': (str,),  # noqa: E501
            'hub_world_id': (WorldID,),  # noqa: E501
            'jobs_email': (str,),  # noqa: E501
            'message_of_the_day': (str,),  # noqa: E501
            'moderation_email': (str,),  # noqa: E501
            'moderation_query_period': (int,),  # noqa: E501
            'not_allowed_to_select_avatar_in_private_world_message': (str,),  # noqa: E501
            'plugin': (str,),  # noqa: E501
            'release_app_version_standalone': (str,),  # noqa: E501
            'release_sdk_url': (str,),  # noqa: E501
            'release_sdk_version': (str,),  # noqa: E501
            'release_server_version_standalone': (str,),  # noqa: E501
            'sdk_developer_faq_url': (str,),  # noqa: E501
            'sdk_discord_url': (str,),  # noqa: E501
            'sdk_not_allowed_to_publish_message': (str,),  # noqa: E501
            'sdk_unity_version': (str,),  # noqa: E501
            'server_name': (str,),  # noqa: E501
            'support_email': (str,),  # noqa: E501
            'time_out_world_id': (WorldID,),  # noqa: E501
            'tutorial_world_id': (WorldID,),  # noqa: E501
            'update_rate_ms_maximum': (int,),  # noqa: E501
            'update_rate_ms_minimum': (int,),  # noqa: E501
            'update_rate_ms_normal': (int,),  # noqa: E501
            'update_rate_ms_udon_manual': (int,),  # noqa: E501
            'upload_analysis_percent': (int,),  # noqa: E501
            'url_list': ([str],),  # noqa: E501
            'use_reliable_udp_for_voice': (bool,),  # noqa: E501
            'user_update_period': (int,),  # noqa: E501
            'user_verification_delay': (int,),  # noqa: E501
            'user_verification_retry': (int,),  # noqa: E501
            'user_verification_timeout': (int,),  # noqa: E501
            'vive_windows_url': (str,),  # noqa: E501
            'white_listed_asset_urls': ([str],),  # noqa: E501
            'world_update_period': (int,),  # noqa: E501
            'player_url_resolver_hash': (str,),  # noqa: E501
            'player_url_resolver_version': (str,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'voice_enable_degradation': 'VoiceEnableDegradation',  # noqa: E501
        'voice_enable_receiver_limiting': 'VoiceEnableReceiverLimiting',  # noqa: E501
        'address': 'address',  # noqa: E501
        'announcements': 'announcements',  # noqa: E501
        'api_key': 'apiKey',  # noqa: E501
        'app_name': 'appName',  # noqa: E501
        'build_version_tag': 'buildVersionTag',  # noqa: E501
        'client_api_key': 'clientApiKey',  # noqa: E501
        'client_bps_ceiling': 'clientBPSCeiling',  # noqa: E501
        'client_disconnect_timeout': 'clientDisconnectTimeout',  # noqa: E501
        'client_reserved_player_bps': 'clientReservedPlayerBPS',  # noqa: E501
        'client_sent_count_allowance': 'clientSentCountAllowance',  # noqa: E501
        'contact_email': 'contactEmail',  # noqa: E501
        'copyright_email': 'copyrightEmail',  # noqa: E501
        'current_tos_version': 'currentTOSVersion',  # noqa: E501
        'default_avatar': 'defaultAvatar',  # noqa: E501
        'deployment_group': 'deploymentGroup',  # noqa: E501
        'dev_app_version_standalone': 'devAppVersionStandalone',  # noqa: E501
        'dev_download_link_windows': 'devDownloadLinkWindows',  # noqa: E501
        'dev_sdk_url': 'devSdkUrl',  # noqa: E501
        'dev_sdk_version': 'devSdkVersion',  # noqa: E501
        'dev_server_version_standalone': 'devServerVersionStandalone',  # noqa: E501
        'dis_countdown': 'dis-countdown',  # noqa: E501
        'disable_avatar_copying': 'disableAvatarCopying',  # noqa: E501
        'disable_avatar_gating': 'disableAvatarGating',  # noqa: E501
        'disable_community_labs': 'disableCommunityLabs',  # noqa: E501
        'disable_community_labs_promotion': 'disableCommunityLabsPromotion',  # noqa: E501
        'disable_email': 'disableEmail',  # noqa: E501
        'disable_event_stream': 'disableEventStream',  # noqa: E501
        'disable_feedback_gating': 'disableFeedbackGating',  # noqa: E501
        'disable_frontend_builds': 'disableFrontendBuilds',  # noqa: E501
        'disable_hello': 'disableHello',  # noqa: E501
        'disable_oculus_subs': 'disableOculusSubs',  # noqa: E501
        'disable_registration': 'disableRegistration',  # noqa: E501
        'disable_steam_networking': 'disableSteamNetworking',  # noqa: E501
        'disable_two_factor_auth': 'disableTwoFactorAuth',  # noqa: E501
        'disable_udon': 'disableUdon',  # noqa: E501
        'disable_upgrade_account': 'disableUpgradeAccount',  # noqa: E501
        'download_link_windows': 'downloadLinkWindows',  # noqa: E501
        'download_urls': 'downloadUrls',  # noqa: E501
        'dynamic_world_rows': 'dynamicWorldRows',  # noqa: E501
        'events': 'events',  # noqa: E501
        'gear_demo_room_id': 'gearDemoRoomId',  # noqa: E501
        'home_world_id': 'homeWorldId',  # noqa: E501
        'homepage_redirect_target': 'homepageRedirectTarget',  # noqa: E501
        'hub_world_id': 'hubWorldId',  # noqa: E501
        'jobs_email': 'jobsEmail',  # noqa: E501
        'message_of_the_day': 'messageOfTheDay',  # noqa: E501
        'moderation_email': 'moderationEmail',  # noqa: E501
        'moderation_query_period': 'moderationQueryPeriod',  # noqa: E501
        'not_allowed_to_select_avatar_in_private_world_message': 'notAllowedToSelectAvatarInPrivateWorldMessage',  # noqa: E501
        'plugin': 'plugin',  # noqa: E501
        'release_app_version_standalone': 'releaseAppVersionStandalone',  # noqa: E501
        'release_sdk_url': 'releaseSdkUrl',  # noqa: E501
        'release_sdk_version': 'releaseSdkVersion',  # noqa: E501
        'release_server_version_standalone': 'releaseServerVersionStandalone',  # noqa: E501
        'sdk_developer_faq_url': 'sdkDeveloperFaqUrl',  # noqa: E501
        'sdk_discord_url': 'sdkDiscordUrl',  # noqa: E501
        'sdk_not_allowed_to_publish_message': 'sdkNotAllowedToPublishMessage',  # noqa: E501
        'sdk_unity_version': 'sdkUnityVersion',  # noqa: E501
        'server_name': 'serverName',  # noqa: E501
        'support_email': 'supportEmail',  # noqa: E501
        'time_out_world_id': 'timeOutWorldId',  # noqa: E501
        'tutorial_world_id': 'tutorialWorldId',  # noqa: E501
        'update_rate_ms_maximum': 'updateRateMsMaximum',  # noqa: E501
        'update_rate_ms_minimum': 'updateRateMsMinimum',  # noqa: E501
        'update_rate_ms_normal': 'updateRateMsNormal',  # noqa: E501
        'update_rate_ms_udon_manual': 'updateRateMsUdonManual',  # noqa: E501
        'upload_analysis_percent': 'uploadAnalysisPercent',  # noqa: E501
        'url_list': 'urlList',  # noqa: E501
        'use_reliable_udp_for_voice': 'useReliableUdpForVoice',  # noqa: E501
        'user_update_period': 'userUpdatePeriod',  # noqa: E501
        'user_verification_delay': 'userVerificationDelay',  # noqa: E501
        'user_verification_retry': 'userVerificationRetry',  # noqa: E501
        'user_verification_timeout': 'userVerificationTimeout',  # noqa: E501
        'vive_windows_url': 'viveWindowsUrl',  # noqa: E501
        'white_listed_asset_urls': 'whiteListedAssetUrls',  # noqa: E501
        'world_update_period': 'worldUpdatePeriod',  # noqa: E501
        'player_url_resolver_hash': 'player-url-resolver-hash',  # noqa: E501
        'player_url_resolver_version': 'player-url-resolver-version',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, address, announcements, api_key, build_version_tag, client_api_key, contact_email, copyright_email, current_tos_version, default_avatar, deployment_group, dev_app_version_standalone, dev_download_link_windows, dev_sdk_url, dev_sdk_version, dev_server_version_standalone, dis_countdown, download_link_windows, download_urls, dynamic_world_rows, events, gear_demo_room_id, home_world_id, hub_world_id, jobs_email, message_of_the_day, moderation_email, moderation_query_period, not_allowed_to_select_avatar_in_private_world_message, plugin, release_app_version_standalone, release_sdk_url, release_sdk_version, release_server_version_standalone, sdk_developer_faq_url, sdk_discord_url, sdk_not_allowed_to_publish_message, sdk_unity_version, server_name, support_email, time_out_world_id, tutorial_world_id, update_rate_ms_maximum, update_rate_ms_minimum, update_rate_ms_normal, update_rate_ms_udon_manual, upload_analysis_percent, url_list, user_update_period, user_verification_delay, user_verification_retry, user_verification_timeout, vive_windows_url, white_listed_asset_urls, world_update_period, player_url_resolver_hash, player_url_resolver_version, *args, **kwargs):  # noqa: E501
        """APIConfig - a model defined in OpenAPI

        Args:
            address (str): VRChat's office address
            announcements ([PublicAnnouncement]): Public Announcements
            api_key (str): apiKey to be used for all other requests
            build_version_tag (str): Build tag of the API server
            client_api_key (str): apiKey to be used for all other requests
            contact_email (str): VRChat's contact email
            copyright_email (str): VRChat's copyright-issues-related email
            current_tos_version (int): Current version number of the Terms of Service
            default_avatar (AvatarID):
            deployment_group (DeploymentGroup):
            dev_app_version_standalone (str): Version number for game development build
            dev_download_link_windows (str): Developer Download link
            dev_sdk_url (str): Link to download the development SDK, use downloadUrls instead
            dev_sdk_version (str): Version of the development SDK
            dev_server_version_standalone (str): Version number for server development build
            dis_countdown (datetime): Unknown, \"dis\" maybe for disconnect?
            download_link_windows (str): Download link for game on the Oculus Rift website.
            download_urls (DownloadURLList):
            dynamic_world_rows ([DynamicContentRow]): Array of DynamicWorldRow objects, used by the game to display the list of world rows
            events (APIEventConfig):
            gear_demo_room_id (str): Unknown
            home_world_id (WorldID):
            hub_world_id (WorldID):
            jobs_email (str): VRChat's job application email
            message_of_the_day (str): MOTD
            moderation_email (str): VRChat's moderation related email
            moderation_query_period (int): Unknown
            not_allowed_to_select_avatar_in_private_world_message (str): Used in-game to notify a user they aren't allowed to select avatars in private worlds
            plugin (str): Extra [plugin](https://doc.photonengine.com/en-us/server/current/plugins/manual) to run in each instance
            release_app_version_standalone (str): Version number for game release build
            release_sdk_url (str): Link to download the release SDK
            release_sdk_version (str): Version of the release SDK
            release_server_version_standalone (str): Version number for server release build
            sdk_developer_faq_url (str): Link to the developer FAQ
            sdk_discord_url (str): Link to the official VRChat Discord
            sdk_not_allowed_to_publish_message (str): Used in the SDK to notify a user they aren't allowed to upload avatars/worlds yet
            sdk_unity_version (str): Unity version supported by the SDK
            server_name (str): Server name of the API server currently responding
            support_email (str): VRChat's support email
            time_out_world_id (WorldID):
            tutorial_world_id (WorldID):
            update_rate_ms_maximum (int): Unknown
            update_rate_ms_minimum (int): Unknown
            update_rate_ms_normal (int): Unknown
            update_rate_ms_udon_manual (int): Unknown
            upload_analysis_percent (int): Unknown
            url_list ([str]): List of allowed URLs that bypass the \"Allow untrusted URL's\" setting in-game
            user_update_period (int): Unknown
            user_verification_delay (int): Unknown
            user_verification_retry (int): Unknown
            user_verification_timeout (int): Unknown
            vive_windows_url (str): Download link for game on the Steam website.
            white_listed_asset_urls ([str]): List of allowed URLs that are allowed to host avatar assets
            world_update_period (int): Unknown
            player_url_resolver_hash (str): Currently used youtube-dl.exe hash in SHA-256-delimited format
            player_url_resolver_version (str): Currently used youtube-dl.exe version

        Keyword Args:
            voice_enable_degradation (bool): Unknown, probably voice optimization testing. defaults to False  # noqa: E501
            voice_enable_receiver_limiting (bool): Unknown, probably voice optimization testing. defaults to True  # noqa: E501
            app_name (str): Game name. defaults to "VrChat"  # noqa: E501
            client_bps_ceiling (int): Unknown. defaults to 18432  # noqa: E501
            client_disconnect_timeout (int): Unknown. defaults to 30000  # noqa: E501
            client_reserved_player_bps (int): Unknown. defaults to 7168  # noqa: E501
            client_sent_count_allowance (int): Unknown. defaults to 15  # noqa: E501
            disable_avatar_copying (bool): Toggles if copying avatars should be disabled. defaults to False  # noqa: E501
            disable_avatar_gating (bool): Toggles if avatar gating should be disabled. Avatar gating restricts uploading of avatars to people with the `system_avatar_access` Tag or `admin_avatar_access` Tag. defaults to False  # noqa: E501
            disable_community_labs (bool): Toggles if the Community Labs should be disabled. defaults to False  # noqa: E501
            disable_community_labs_promotion (bool): Toggles if promotion out of Community Labs should be disabled. defaults to False  # noqa: E501
            disable_email (bool): Unknown. defaults to False  # noqa: E501
            disable_event_stream (bool): Toggles if Analytics should be disabled.. defaults to False  # noqa: E501
            disable_feedback_gating (bool): Toggles if feedback gating should be disabled. Feedback gating restricts submission of feedback (reporting a World or User) to people with the `system_feedback_access` Tag.. defaults to False  # noqa: E501
            disable_frontend_builds (bool): Unknown, probably toggles compilation of frontend web builds? So internal flag?. defaults to False  # noqa: E501
            disable_hello (bool): Unknown. defaults to False  # noqa: E501
            disable_oculus_subs (bool): Toggles if signing up for Subscriptions in Oculus is disabled or not.. defaults to False  # noqa: E501
            disable_registration (bool): Toggles if new user account registration should be disabled.. defaults to False  # noqa: E501
            disable_steam_networking (bool): Toggles if Steam Networking should be disabled. VRChat these days uses Photon Unity Networking (PUN) instead.. defaults to True  # noqa: E501
            disable_two_factor_auth (bool): Toggles if 2FA should be disabled.. defaults to False  # noqa: E501
            disable_udon (bool): Toggles if Udon should be universally disabled in-game.. defaults to False  # noqa: E501
            disable_upgrade_account (bool): Toggles if account upgrading \"linking with Steam/Oculus\" should be disabled.. defaults to False  # noqa: E501
            homepage_redirect_target (str): Redirect target if you try to open the base API domain in your browser. defaults to "https://hello.vrchat.com"  # noqa: E501
            use_reliable_udp_for_voice (bool): Unknown. defaults to False  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
        """

        voice_enable_degradation = kwargs.get('voice_enable_degradation', False)
        voice_enable_receiver_limiting = kwargs.get('voice_enable_receiver_limiting', True)
        app_name = kwargs.get('app_name', "VrChat")
        client_bps_ceiling = kwargs.get('client_bps_ceiling', 18432)
        client_disconnect_timeout = kwargs.get('client_disconnect_timeout', 30000)
        client_reserved_player_bps = kwargs.get('client_reserved_player_bps', 7168)
        client_sent_count_allowance = kwargs.get('client_sent_count_allowance', 15)
        disable_avatar_copying = kwargs.get('disable_avatar_copying', False)
        disable_avatar_gating = kwargs.get('disable_avatar_gating', False)
        disable_community_labs = kwargs.get('disable_community_labs', False)
        disable_community_labs_promotion = kwargs.get('disable_community_labs_promotion', False)
        disable_email = kwargs.get('disable_email', False)
        disable_event_stream = kwargs.get('disable_event_stream', False)
        disable_feedback_gating = kwargs.get('disable_feedback_gating', False)
        disable_frontend_builds = kwargs.get('disable_frontend_builds', False)
        disable_hello = kwargs.get('disable_hello', False)
        disable_oculus_subs = kwargs.get('disable_oculus_subs', False)
        disable_registration = kwargs.get('disable_registration', False)
        disable_steam_networking = kwargs.get('disable_steam_networking', True)
        disable_two_factor_auth = kwargs.get('disable_two_factor_auth', False)
        disable_udon = kwargs.get('disable_udon', False)
        disable_upgrade_account = kwargs.get('disable_upgrade_account', False)
        homepage_redirect_target = kwargs.get('homepage_redirect_target', "https://hello.vrchat.com")
        use_reliable_udp_for_voice = kwargs.get('use_reliable_udp_for_voice', False)
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.voice_enable_degradation = voice_enable_degradation
        self.voice_enable_receiver_limiting = voice_enable_receiver_limiting
        self.address = address
        self.announcements = announcements
        self.api_key = api_key
        self.app_name = app_name
        self.build_version_tag = build_version_tag
        self.client_api_key = client_api_key
        self.client_bps_ceiling = client_bps_ceiling
        self.client_disconnect_timeout = client_disconnect_timeout
        self.client_reserved_player_bps = client_reserved_player_bps
        self.client_sent_count_allowance = client_sent_count_allowance
        self.contact_email = contact_email
        self.copyright_email = copyright_email
        self.current_tos_version = current_tos_version
        self.default_avatar = default_avatar
        self.deployment_group = deployment_group
        self.dev_app_version_standalone = dev_app_version_standalone
        self.dev_download_link_windows = dev_download_link_windows
        self.dev_sdk_url = dev_sdk_url
        self.dev_sdk_version = dev_sdk_version
        self.dev_server_version_standalone = dev_server_version_standalone
        self.dis_countdown = dis_countdown
        self.disable_avatar_copying = disable_avatar_copying
        self.disable_avatar_gating = disable_avatar_gating
        self.disable_community_labs = disable_community_labs
        self.disable_community_labs_promotion = disable_community_labs_promotion
        self.disable_email = disable_email
        self.disable_event_stream = disable_event_stream
        self.disable_feedback_gating = disable_feedback_gating
        self.disable_frontend_builds = disable_frontend_builds
        self.disable_hello = disable_hello
        self.disable_oculus_subs = disable_oculus_subs
        self.disable_registration = disable_registration
        self.disable_steam_networking = disable_steam_networking
        self.disable_two_factor_auth = disable_two_factor_auth
        self.disable_udon = disable_udon
        self.disable_upgrade_account = disable_upgrade_account
        self.download_link_windows = download_link_windows
        self.download_urls = download_urls
        self.dynamic_world_rows = dynamic_world_rows
        self.events = events
        self.gear_demo_room_id = gear_demo_room_id
        self.home_world_id = home_world_id
        self.homepage_redirect_target = homepage_redirect_target
        self.hub_world_id = hub_world_id
        self.jobs_email = jobs_email
        self.message_of_the_day = message_of_the_day
        self.moderation_email = moderation_email
        self.moderation_query_period = moderation_query_period
        self.not_allowed_to_select_avatar_in_private_world_message = not_allowed_to_select_avatar_in_private_world_message
        self.plugin = plugin
        self.release_app_version_standalone = release_app_version_standalone
        self.release_sdk_url = release_sdk_url
        self.release_sdk_version = release_sdk_version
        self.release_server_version_standalone = release_server_version_standalone
        self.sdk_developer_faq_url = sdk_developer_faq_url
        self.sdk_discord_url = sdk_discord_url
        self.sdk_not_allowed_to_publish_message = sdk_not_allowed_to_publish_message
        self.sdk_unity_version = sdk_unity_version
        self.server_name = server_name
        self.support_email = support_email
        self.time_out_world_id = time_out_world_id
        self.tutorial_world_id = tutorial_world_id
        self.update_rate_ms_maximum = update_rate_ms_maximum
        self.update_rate_ms_minimum = update_rate_ms_minimum
        self.update_rate_ms_normal = update_rate_ms_normal
        self.update_rate_ms_udon_manual = update_rate_ms_udon_manual
        self.upload_analysis_percent = upload_analysis_percent
        self.url_list = url_list
        self.use_reliable_udp_for_voice = use_reliable_udp_for_voice
        self.user_update_period = user_update_period
        self.user_verification_delay = user_verification_delay
        self.user_verification_retry = user_verification_retry
        self.user_verification_timeout = user_verification_timeout
        self.vive_windows_url = vive_windows_url
        self.white_listed_asset_urls = white_listed_asset_urls
        self.world_update_period = world_update_period
        self.player_url_resolver_hash = player_url_resolver_hash
        self.player_url_resolver_version = player_url_resolver_version
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, address, announcements, api_key, build_version_tag, client_api_key, contact_email, copyright_email, current_tos_version, default_avatar, deployment_group, dev_app_version_standalone, dev_download_link_windows, dev_sdk_url, dev_sdk_version, dev_server_version_standalone, dis_countdown, download_link_windows, download_urls, dynamic_world_rows, events, gear_demo_room_id, home_world_id, hub_world_id, jobs_email, message_of_the_day, moderation_email, moderation_query_period, not_allowed_to_select_avatar_in_private_world_message, plugin, release_app_version_standalone, release_sdk_url, release_sdk_version, release_server_version_standalone, sdk_developer_faq_url, sdk_discord_url, sdk_not_allowed_to_publish_message, sdk_unity_version, server_name, support_email, time_out_world_id, tutorial_world_id, update_rate_ms_maximum, update_rate_ms_minimum, update_rate_ms_normal, update_rate_ms_udon_manual, upload_analysis_percent, url_list, user_update_period, user_verification_delay, user_verification_retry, user_verification_timeout, vive_windows_url, white_listed_asset_urls, world_update_period, player_url_resolver_hash, player_url_resolver_version, *args, **kwargs):  # noqa: E501
        """APIConfig - a model defined in OpenAPI

        Args:
            address (str): VRChat's office address
            announcements ([PublicAnnouncement]): Public Announcements
            api_key (str): apiKey to be used for all other requests
            build_version_tag (str): Build tag of the API server
            client_api_key (str): apiKey to be used for all other requests
            contact_email (str): VRChat's contact email
            copyright_email (str): VRChat's copyright-issues-related email
            current_tos_version (int): Current version number of the Terms of Service
            default_avatar (AvatarID):
            deployment_group (DeploymentGroup):
            dev_app_version_standalone (str): Version number for game development build
            dev_download_link_windows (str): Developer Download link
            dev_sdk_url (str): Link to download the development SDK, use downloadUrls instead
            dev_sdk_version (str): Version of the development SDK
            dev_server_version_standalone (str): Version number for server development build
            dis_countdown (datetime): Unknown, \"dis\" maybe for disconnect?
            download_link_windows (str): Download link for game on the Oculus Rift website.
            download_urls (DownloadURLList):
            dynamic_world_rows ([DynamicContentRow]): Array of DynamicWorldRow objects, used by the game to display the list of world rows
            events (APIEventConfig):
            gear_demo_room_id (str): Unknown
            home_world_id (WorldID):
            hub_world_id (WorldID):
            jobs_email (str): VRChat's job application email
            message_of_the_day (str): MOTD
            moderation_email (str): VRChat's moderation related email
            moderation_query_period (int): Unknown
            not_allowed_to_select_avatar_in_private_world_message (str): Used in-game to notify a user they aren't allowed to select avatars in private worlds
            plugin (str): Extra [plugin](https://doc.photonengine.com/en-us/server/current/plugins/manual) to run in each instance
            release_app_version_standalone (str): Version number for game release build
            release_sdk_url (str): Link to download the release SDK
            release_sdk_version (str): Version of the release SDK
            release_server_version_standalone (str): Version number for server release build
            sdk_developer_faq_url (str): Link to the developer FAQ
            sdk_discord_url (str): Link to the official VRChat Discord
            sdk_not_allowed_to_publish_message (str): Used in the SDK to notify a user they aren't allowed to upload avatars/worlds yet
            sdk_unity_version (str): Unity version supported by the SDK
            server_name (str): Server name of the API server currently responding
            support_email (str): VRChat's support email
            time_out_world_id (WorldID):
            tutorial_world_id (WorldID):
            update_rate_ms_maximum (int): Unknown
            update_rate_ms_minimum (int): Unknown
            update_rate_ms_normal (int): Unknown
            update_rate_ms_udon_manual (int): Unknown
            upload_analysis_percent (int): Unknown
            url_list ([str]): List of allowed URLs that bypass the \"Allow untrusted URL's\" setting in-game
            user_update_period (int): Unknown
            user_verification_delay (int): Unknown
            user_verification_retry (int): Unknown
            user_verification_timeout (int): Unknown
            vive_windows_url (str): Download link for game on the Steam website.
            white_listed_asset_urls ([str]): List of allowed URLs that are allowed to host avatar assets
            world_update_period (int): Unknown
            player_url_resolver_hash (str): Currently used youtube-dl.exe hash in SHA-256-delimited format
            player_url_resolver_version (str): Currently used youtube-dl.exe version

        Keyword Args:
            voice_enable_degradation (bool): Unknown, probably voice optimization testing. defaults to False  # noqa: E501
            voice_enable_receiver_limiting (bool): Unknown, probably voice optimization testing. defaults to True  # noqa: E501
            app_name (str): Game name. defaults to "VrChat"  # noqa: E501
            client_bps_ceiling (int): Unknown. defaults to 18432  # noqa: E501
            client_disconnect_timeout (int): Unknown. defaults to 30000  # noqa: E501
            client_reserved_player_bps (int): Unknown. defaults to 7168  # noqa: E501
            client_sent_count_allowance (int): Unknown. defaults to 15  # noqa: E501
            disable_avatar_copying (bool): Toggles if copying avatars should be disabled. defaults to False  # noqa: E501
            disable_avatar_gating (bool): Toggles if avatar gating should be disabled. Avatar gating restricts uploading of avatars to people with the `system_avatar_access` Tag or `admin_avatar_access` Tag. defaults to False  # noqa: E501
            disable_community_labs (bool): Toggles if the Community Labs should be disabled. defaults to False  # noqa: E501
            disable_community_labs_promotion (bool): Toggles if promotion out of Community Labs should be disabled. defaults to False  # noqa: E501
            disable_email (bool): Unknown. defaults to False  # noqa: E501
            disable_event_stream (bool): Toggles if Analytics should be disabled.. defaults to False  # noqa: E501
            disable_feedback_gating (bool): Toggles if feedback gating should be disabled. Feedback gating restricts submission of feedback (reporting a World or User) to people with the `system_feedback_access` Tag.. defaults to False  # noqa: E501
            disable_frontend_builds (bool): Unknown, probably toggles compilation of frontend web builds? So internal flag?. defaults to False  # noqa: E501
            disable_hello (bool): Unknown. defaults to False  # noqa: E501
            disable_oculus_subs (bool): Toggles if signing up for Subscriptions in Oculus is disabled or not.. defaults to False  # noqa: E501
            disable_registration (bool): Toggles if new user account registration should be disabled.. defaults to False  # noqa: E501
            disable_steam_networking (bool): Toggles if Steam Networking should be disabled. VRChat these days uses Photon Unity Networking (PUN) instead.. defaults to True  # noqa: E501
            disable_two_factor_auth (bool): Toggles if 2FA should be disabled.. defaults to False  # noqa: E501
            disable_udon (bool): Toggles if Udon should be universally disabled in-game.. defaults to False  # noqa: E501
            disable_upgrade_account (bool): Toggles if account upgrading \"linking with Steam/Oculus\" should be disabled.. defaults to False  # noqa: E501
            homepage_redirect_target (str): Redirect target if you try to open the base API domain in your browser. defaults to "https://hello.vrchat.com"  # noqa: E501
            use_reliable_udp_for_voice (bool): Unknown. defaults to False  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
        """

        voice_enable_degradation = kwargs.get('voice_enable_degradation', False)
        voice_enable_receiver_limiting = kwargs.get('voice_enable_receiver_limiting', True)
        app_name = kwargs.get('app_name', "VrChat")
        client_bps_ceiling = kwargs.get('client_bps_ceiling', 18432)
        client_disconnect_timeout = kwargs.get('client_disconnect_timeout', 30000)
        client_reserved_player_bps = kwargs.get('client_reserved_player_bps', 7168)
        client_sent_count_allowance = kwargs.get('client_sent_count_allowance', 15)
        disable_avatar_copying = kwargs.get('disable_avatar_copying', False)
        disable_avatar_gating = kwargs.get('disable_avatar_gating', False)
        disable_community_labs = kwargs.get('disable_community_labs', False)
        disable_community_labs_promotion = kwargs.get('disable_community_labs_promotion', False)
        disable_email = kwargs.get('disable_email', False)
        disable_event_stream = kwargs.get('disable_event_stream', False)
        disable_feedback_gating = kwargs.get('disable_feedback_gating', False)
        disable_frontend_builds = kwargs.get('disable_frontend_builds', False)
        disable_hello = kwargs.get('disable_hello', False)
        disable_oculus_subs = kwargs.get('disable_oculus_subs', False)
        disable_registration = kwargs.get('disable_registration', False)
        disable_steam_networking = kwargs.get('disable_steam_networking', True)
        disable_two_factor_auth = kwargs.get('disable_two_factor_auth', False)
        disable_udon = kwargs.get('disable_udon', False)
        disable_upgrade_account = kwargs.get('disable_upgrade_account', False)
        homepage_redirect_target = kwargs.get('homepage_redirect_target', "https://hello.vrchat.com")
        use_reliable_udp_for_voice = kwargs.get('use_reliable_udp_for_voice', False)
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.voice_enable_degradation = voice_enable_degradation
        self.voice_enable_receiver_limiting = voice_enable_receiver_limiting
        self.address = address
        self.announcements = announcements
        self.api_key = api_key
        self.app_name = app_name
        self.build_version_tag = build_version_tag
        self.client_api_key = client_api_key
        self.client_bps_ceiling = client_bps_ceiling
        self.client_disconnect_timeout = client_disconnect_timeout
        self.client_reserved_player_bps = client_reserved_player_bps
        self.client_sent_count_allowance = client_sent_count_allowance
        self.contact_email = contact_email
        self.copyright_email = copyright_email
        self.current_tos_version = current_tos_version
        self.default_avatar = default_avatar
        self.deployment_group = deployment_group
        self.dev_app_version_standalone = dev_app_version_standalone
        self.dev_download_link_windows = dev_download_link_windows
        self.dev_sdk_url = dev_sdk_url
        self.dev_sdk_version = dev_sdk_version
        self.dev_server_version_standalone = dev_server_version_standalone
        self.dis_countdown = dis_countdown
        self.disable_avatar_copying = disable_avatar_copying
        self.disable_avatar_gating = disable_avatar_gating
        self.disable_community_labs = disable_community_labs
        self.disable_community_labs_promotion = disable_community_labs_promotion
        self.disable_email = disable_email
        self.disable_event_stream = disable_event_stream
        self.disable_feedback_gating = disable_feedback_gating
        self.disable_frontend_builds = disable_frontend_builds
        self.disable_hello = disable_hello
        self.disable_oculus_subs = disable_oculus_subs
        self.disable_registration = disable_registration
        self.disable_steam_networking = disable_steam_networking
        self.disable_two_factor_auth = disable_two_factor_auth
        self.disable_udon = disable_udon
        self.disable_upgrade_account = disable_upgrade_account
        self.download_link_windows = download_link_windows
        self.download_urls = download_urls
        self.dynamic_world_rows = dynamic_world_rows
        self.events = events
        self.gear_demo_room_id = gear_demo_room_id
        self.home_world_id = home_world_id
        self.homepage_redirect_target = homepage_redirect_target
        self.hub_world_id = hub_world_id
        self.jobs_email = jobs_email
        self.message_of_the_day = message_of_the_day
        self.moderation_email = moderation_email
        self.moderation_query_period = moderation_query_period
        self.not_allowed_to_select_avatar_in_private_world_message = not_allowed_to_select_avatar_in_private_world_message
        self.plugin = plugin
        self.release_app_version_standalone = release_app_version_standalone
        self.release_sdk_url = release_sdk_url
        self.release_sdk_version = release_sdk_version
        self.release_server_version_standalone = release_server_version_standalone
        self.sdk_developer_faq_url = sdk_developer_faq_url
        self.sdk_discord_url = sdk_discord_url
        self.sdk_not_allowed_to_publish_message = sdk_not_allowed_to_publish_message
        self.sdk_unity_version = sdk_unity_version
        self.server_name = server_name
        self.support_email = support_email
        self.time_out_world_id = time_out_world_id
        self.tutorial_world_id = tutorial_world_id
        self.update_rate_ms_maximum = update_rate_ms_maximum
        self.update_rate_ms_minimum = update_rate_ms_minimum
        self.update_rate_ms_normal = update_rate_ms_normal
        self.update_rate_ms_udon_manual = update_rate_ms_udon_manual
        self.upload_analysis_percent = upload_analysis_percent
        self.url_list = url_list
        self.use_reliable_udp_for_voice = use_reliable_udp_for_voice
        self.user_update_period = user_update_period
        self.user_verification_delay = user_verification_delay
        self.user_verification_retry = user_verification_retry
        self.user_verification_timeout = user_verification_timeout
        self.vive_windows_url = vive_windows_url
        self.white_listed_asset_urls = white_listed_asset_urls
        self.world_update_period = world_update_period
        self.player_url_resolver_hash = player_url_resolver_hash
        self.player_url_resolver_version = player_url_resolver_version
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



"""
    VRChat API Documentation


    The version of the OpenAPI document: 1.7.3
    Contact: me@ariesclark.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from vrchatapi.api_client import ApiClient, Endpoint as _Endpoint
from vrchatapi.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from vrchatapi.model.avatar import Avatar
from vrchatapi.model.create_avatar_request import CreateAvatarRequest
from vrchatapi.model.current_user import CurrentUser
from vrchatapi.model.error import Error
from vrchatapi.model.update_avatar_request import UpdateAvatarRequest


class AvatarsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_avatar_endpoint = _Endpoint(
            settings={
                'response_type': (Avatar,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/avatars',
                'operation_id': 'create_avatar',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'create_avatar_request',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'create_avatar_request':
                        (CreateAvatarRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'create_avatar_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_avatar_endpoint = _Endpoint(
            settings={
                'response_type': (Avatar,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/avatars/{avatarId}',
                'operation_id': 'delete_avatar',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'avatar_id',
                ],
                'required': [
                    'avatar_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'avatar_id':
                        (str,),
                },
                'attribute_map': {
                    'avatar_id': 'avatarId',
                },
                'location_map': {
                    'avatar_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_avatar_endpoint = _Endpoint(
            settings={
                'response_type': (Avatar,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/avatars/{avatarId}',
                'operation_id': 'get_avatar',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'avatar_id',
                ],
                'required': [
                    'avatar_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'avatar_id':
                        (str,),
                },
                'attribute_map': {
                    'avatar_id': 'avatarId',
                },
                'location_map': {
                    'avatar_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_favorited_avatars_endpoint = _Endpoint(
            settings={
                'response_type': ([Avatar],),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/avatars/favorites',
                'operation_id': 'get_favorited_avatars',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'featured',
                    'sort',
                    'n',
                    'order',
                    'offset',
                    'search',
                    'tag',
                    'notag',
                    'release_status',
                    'max_unity_version',
                    'min_unity_version',
                    'platform',
                    'user_id',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'sort',
                    'order',
                    'release_status',
                ],
                'validation': [
                    'n',
                    'offset',
                ]
            },
            root_map={
                'validations': {
                    ('n',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                    ('offset',): {

                        'inclusive_minimum': 0,
                    },
                },
                'allowed_values': {
                    ('sort',): {

                        "POPULARITY": "popularity",
                        "HEAT": "heat",
                        "TRUST": "trust",
                        "SHUFFLE": "shuffle",
                        "RANDOM": "random",
                        "FAVORITES": "favorites",
                        "REPORTSCORE": "reportScore",
                        "REPORTCOUNT": "reportCount",
                        "PUBLICATIONDATE": "publicationDate",
                        "LABSPUBLICATIONDATE": "labsPublicationDate",
                        "CREATED": "created",
                        "_CREATED_AT": "_created_at",
                        "UPDATED": "updated",
                        "_UPDATED_AT": "_updated_at",
                        "ORDER": "order",
                        "RELEVANCE": "relevance",
                        "MAGIC": "magic",
                        "NAME": "name"
                    },
                    ('order',): {

                        "ASCENDING": "ascending",
                        "DESCENDING": "descending"
                    },
                    ('release_status',): {

                        "PUBLIC": "public",
                        "PRIVATE": "private",
                        "HIDDEN": "hidden",
                        "ALL": "all"
                    },
                },
                'openapi_types': {
                    'featured':
                        (bool,),
                    'sort':
                        (str,),
                    'n':
                        (int,),
                    'order':
                        (str,),
                    'offset':
                        (int,),
                    'search':
                        (str,),
                    'tag':
                        (str,),
                    'notag':
                        (str,),
                    'release_status':
                        (str,),
                    'max_unity_version':
                        (str,),
                    'min_unity_version':
                        (str,),
                    'platform':
                        (str,),
                    'user_id':
                        (str,),
                },
                'attribute_map': {
                    'featured': 'featured',
                    'sort': 'sort',
                    'n': 'n',
                    'order': 'order',
                    'offset': 'offset',
                    'search': 'search',
                    'tag': 'tag',
                    'notag': 'notag',
                    'release_status': 'releaseStatus',
                    'max_unity_version': 'maxUnityVersion',
                    'min_unity_version': 'minUnityVersion',
                    'platform': 'platform',
                    'user_id': 'userId',
                },
                'location_map': {
                    'featured': 'query',
                    'sort': 'query',
                    'n': 'query',
                    'order': 'query',
                    'offset': 'query',
                    'search': 'query',
                    'tag': 'query',
                    'notag': 'query',
                    'release_status': 'query',
                    'max_unity_version': 'query',
                    'min_unity_version': 'query',
                    'platform': 'query',
                    'user_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.search_avatars_endpoint = _Endpoint(
            settings={
                'response_type': ([Avatar],),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/avatars',
                'operation_id': 'search_avatars',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'featured',
                    'sort',
                    'user',
                    'user_id',
                    'n',
                    'order',
                    'offset',
                    'tag',
                    'notag',
                    'release_status',
                    'max_unity_version',
                    'min_unity_version',
                    'platform',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'sort',
                    'user',
                    'order',
                    'release_status',
                ],
                'validation': [
                    'n',
                    'offset',
                ]
            },
            root_map={
                'validations': {
                    ('n',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                    ('offset',): {

                        'inclusive_minimum': 0,
                    },
                },
                'allowed_values': {
                    ('sort',): {

                        "POPULARITY": "popularity",
                        "HEAT": "heat",
                        "TRUST": "trust",
                        "SHUFFLE": "shuffle",
                        "RANDOM": "random",
                        "FAVORITES": "favorites",
                        "REPORTSCORE": "reportScore",
                        "REPORTCOUNT": "reportCount",
                        "PUBLICATIONDATE": "publicationDate",
                        "LABSPUBLICATIONDATE": "labsPublicationDate",
                        "CREATED": "created",
                        "_CREATED_AT": "_created_at",
                        "UPDATED": "updated",
                        "_UPDATED_AT": "_updated_at",
                        "ORDER": "order",
                        "RELEVANCE": "relevance",
                        "MAGIC": "magic",
                        "NAME": "name"
                    },
                    ('user',): {

                        "ME": "me"
                    },
                    ('order',): {

                        "ASCENDING": "ascending",
                        "DESCENDING": "descending"
                    },
                    ('release_status',): {

                        "PUBLIC": "public",
                        "PRIVATE": "private",
                        "HIDDEN": "hidden",
                        "ALL": "all"
                    },
                },
                'openapi_types': {
                    'featured':
                        (bool,),
                    'sort':
                        (str,),
                    'user':
                        (str,),
                    'user_id':
                        (str,),
                    'n':
                        (int,),
                    'order':
                        (str,),
                    'offset':
                        (int,),
                    'tag':
                        (str,),
                    'notag':
                        (str,),
                    'release_status':
                        (str,),
                    'max_unity_version':
                        (str,),
                    'min_unity_version':
                        (str,),
                    'platform':
                        (str,),
                },
                'attribute_map': {
                    'featured': 'featured',
                    'sort': 'sort',
                    'user': 'user',
                    'user_id': 'userId',
                    'n': 'n',
                    'order': 'order',
                    'offset': 'offset',
                    'tag': 'tag',
                    'notag': 'notag',
                    'release_status': 'releaseStatus',
                    'max_unity_version': 'maxUnityVersion',
                    'min_unity_version': 'minUnityVersion',
                    'platform': 'platform',
                },
                'location_map': {
                    'featured': 'query',
                    'sort': 'query',
                    'user': 'query',
                    'user_id': 'query',
                    'n': 'query',
                    'order': 'query',
                    'offset': 'query',
                    'tag': 'query',
                    'notag': 'query',
                    'release_status': 'query',
                    'max_unity_version': 'query',
                    'min_unity_version': 'query',
                    'platform': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.select_avatar_endpoint = _Endpoint(
            settings={
                'response_type': (CurrentUser,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/avatars/{avatarId}/select',
                'operation_id': 'select_avatar',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'avatar_id',
                ],
                'required': [
                    'avatar_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'avatar_id':
                        (str,),
                },
                'attribute_map': {
                    'avatar_id': 'avatarId',
                },
                'location_map': {
                    'avatar_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.select_fallback_avatar_endpoint = _Endpoint(
            settings={
                'response_type': (CurrentUser,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/avatars/{avatarId}/selectFallback',
                'operation_id': 'select_fallback_avatar',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'avatar_id',
                ],
                'required': [
                    'avatar_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'avatar_id':
                        (str,),
                },
                'attribute_map': {
                    'avatar_id': 'avatarId',
                },
                'location_map': {
                    'avatar_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_avatar_endpoint = _Endpoint(
            settings={
                'response_type': (Avatar,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/avatars/{avatarId}',
                'operation_id': 'update_avatar',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'avatar_id',
                    'update_avatar_request',
                ],
                'required': [
                    'avatar_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'avatar_id':
                        (str,),
                    'update_avatar_request':
                        (UpdateAvatarRequest,),
                },
                'attribute_map': {
                    'avatar_id': 'avatarId',
                },
                'location_map': {
                    'avatar_id': 'path',
                    'update_avatar_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def create_avatar(
        self,
        **kwargs
    ):
        """Create Avatar  # noqa: E501

        Create an avatar. It's possible to optionally specify a ID if you want a custom one. Attempting to create an Avatar with an already claimed ID will result in a DB error.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_avatar(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            create_avatar_request (CreateAvatarRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Avatar
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.create_avatar_endpoint.call_with_http_info(**kwargs)

    def delete_avatar(
        self,
        avatar_id,
        **kwargs
    ):
        """Delete Avatar  # noqa: E501

        Delete an avatar. Notice an avatar is never fully \"deleted\", only its ReleaseStatus is set to \"hidden\" and the linked Files are deleted. The AvatarID is permanently reserved.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_avatar(avatar_id, async_req=True)
        >>> result = thread.get()

        Args:
            avatar_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Avatar
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['avatar_id'] = \
            avatar_id
        return self.delete_avatar_endpoint.call_with_http_info(**kwargs)

    def get_avatar(
        self,
        avatar_id,
        **kwargs
    ):
        """Get Avatar  # noqa: E501

        Get information about a specific Avatar.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_avatar(avatar_id, async_req=True)
        >>> result = thread.get()

        Args:
            avatar_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Avatar
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['avatar_id'] = \
            avatar_id
        return self.get_avatar_endpoint.call_with_http_info(**kwargs)

    def get_favorited_avatars(
        self,
        **kwargs
    ):
        """List Favorited Avatars  # noqa: E501

        Search and list favorited avatars by query filters.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_favorited_avatars(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            featured (bool): Filters on featured results.. [optional]
            sort (str): [optional] if omitted the server will use the default value of "popularity"
            n (int): The number of objects to return.. [optional] if omitted the server will use the default value of 60
            order (str): [optional] if omitted the server will use the default value of "descending"
            offset (int): A zero-based offset from the default object sorting from where search results start.. [optional]
            search (str): Filters by world name.. [optional]
            tag (str): Tags to include (comma-separated). Any of the tags needs to be present.. [optional]
            notag (str): Tags to exclude (comma-separated).. [optional]
            release_status (str): Filter by ReleaseStatus.. [optional] if omitted the server will use the default value of "public"
            max_unity_version (str): The maximum Unity version supported by the asset.. [optional]
            min_unity_version (str): The minimum Unity version supported by the asset.. [optional]
            platform (str): The platform the asset supports.. [optional]
            user_id (str): Target user to see information on, admin-only.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [Avatar]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_favorited_avatars_endpoint.call_with_http_info(**kwargs)

    def search_avatars(
        self,
        **kwargs
    ):
        """Search Avatars  # noqa: E501

        Search and list avatars by query filters. You can only search your own or featured avatars. It is not possible as a normal user to search other peoples avatars.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search_avatars(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            featured (bool): Filters on featured results.. [optional]
            sort (str): [optional] if omitted the server will use the default value of "popularity"
            user (str): Set to `me` for searching own avatars.. [optional] if omitted the server will use the default value of "me"
            user_id (str): Filter by UserID.. [optional]
            n (int): The number of objects to return.. [optional] if omitted the server will use the default value of 60
            order (str): [optional] if omitted the server will use the default value of "descending"
            offset (int): A zero-based offset from the default object sorting from where search results start.. [optional]
            tag (str): Tags to include (comma-separated). Any of the tags needs to be present.. [optional]
            notag (str): Tags to exclude (comma-separated).. [optional]
            release_status (str): Filter by ReleaseStatus.. [optional] if omitted the server will use the default value of "public"
            max_unity_version (str): The maximum Unity version supported by the asset.. [optional]
            min_unity_version (str): The minimum Unity version supported by the asset.. [optional]
            platform (str): The platform the asset supports.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [Avatar]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.search_avatars_endpoint.call_with_http_info(**kwargs)

    def select_avatar(
        self,
        avatar_id,
        **kwargs
    ):
        """Select Avatar  # noqa: E501

        Switches into that avatar.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.select_avatar(avatar_id, async_req=True)
        >>> result = thread.get()

        Args:
            avatar_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CurrentUser
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['avatar_id'] = \
            avatar_id
        return self.select_avatar_endpoint.call_with_http_info(**kwargs)

    def select_fallback_avatar(
        self,
        avatar_id,
        **kwargs
    ):
        """Select Fallback Avatar  # noqa: E501

        Switches into that avatar as your fallback avatar.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.select_fallback_avatar(avatar_id, async_req=True)
        >>> result = thread.get()

        Args:
            avatar_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            CurrentUser
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['avatar_id'] = \
            avatar_id
        return self.select_fallback_avatar_endpoint.call_with_http_info(**kwargs)

    def update_avatar(
        self,
        avatar_id,
        **kwargs
    ):
        """Update Avatar  # noqa: E501

        Update information about a specific avatar.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_avatar(avatar_id, async_req=True)
        >>> result = thread.get()

        Args:
            avatar_id (str):

        Keyword Args:
            update_avatar_request (UpdateAvatarRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Avatar
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['avatar_id'] = \
            avatar_id
        return self.update_avatar_endpoint.call_with_http_info(**kwargs)




"""
    VRChat API Documentation


    The version of the OpenAPI document: 1.7.3
    Contact: me@ariesclark.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from vrchatapi.api_client import ApiClient, Endpoint as _Endpoint
from vrchatapi.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from vrchatapi.model.add_favorite_request import AddFavoriteRequest
from vrchatapi.model.error import Error
from vrchatapi.model.favorite import Favorite
from vrchatapi.model.favorite_group import FavoriteGroup
from vrchatapi.model.success import Success
from vrchatapi.model.update_favorite_group_request import UpdateFavoriteGroupRequest


class FavoritesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.add_favorite_endpoint = _Endpoint(
            settings={
                'response_type': (Favorite,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/favorites',
                'operation_id': 'add_favorite',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'add_favorite_request',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'add_favorite_request':
                        (AddFavoriteRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'add_favorite_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.clear_favorite_group_endpoint = _Endpoint(
            settings={
                'response_type': (Success,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/favorite/group/{favoriteGroupType}/{favoriteGroupName}/{userId}',
                'operation_id': 'clear_favorite_group',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'favorite_group_type',
                    'favorite_group_name',
                    'user_id',
                ],
                'required': [
                    'favorite_group_type',
                    'favorite_group_name',
                    'user_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'favorite_group_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('favorite_group_type',): {

                        "WORLD": "world",
                        "FRIEND": "friend",
                        "AVATAR": "avatar"
                    },
                },
                'openapi_types': {
                    'favorite_group_type':
                        (str,),
                    'favorite_group_name':
                        (str,),
                    'user_id':
                        (str,),
                },
                'attribute_map': {
                    'favorite_group_type': 'favoriteGroupType',
                    'favorite_group_name': 'favoriteGroupName',
                    'user_id': 'userId',
                },
                'location_map': {
                    'favorite_group_type': 'path',
                    'favorite_group_name': 'path',
                    'user_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_favorite_endpoint = _Endpoint(
            settings={
                'response_type': (Favorite,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/favorites/{favoriteId}',
                'operation_id': 'get_favorite',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'favorite_id',
                ],
                'required': [
                    'favorite_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'favorite_id':
                        (str,),
                },
                'attribute_map': {
                    'favorite_id': 'favoriteId',
                },
                'location_map': {
                    'favorite_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_favorite_group_endpoint = _Endpoint(
            settings={
                'response_type': (FavoriteGroup,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/favorite/group/{favoriteGroupType}/{favoriteGroupName}/{userId}',
                'operation_id': 'get_favorite_group',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'favorite_group_type',
                    'favorite_group_name',
                    'user_id',
                ],
                'required': [
                    'favorite_group_type',
                    'favorite_group_name',
                    'user_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'favorite_group_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('favorite_group_type',): {

                        "WORLD": "world",
                        "FRIEND": "friend",
                        "AVATAR": "avatar"
                    },
                },
                'openapi_types': {
                    'favorite_group_type':
                        (str,),
                    'favorite_group_name':
                        (str,),
                    'user_id':
                        (str,),
                },
                'attribute_map': {
                    'favorite_group_type': 'favoriteGroupType',
                    'favorite_group_name': 'favoriteGroupName',
                    'user_id': 'userId',
                },
                'location_map': {
                    'favorite_group_type': 'path',
                    'favorite_group_name': 'path',
                    'user_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_favorite_groups_endpoint = _Endpoint(
            settings={
                'response_type': ([FavoriteGroup],),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/favorite/groups',
                'operation_id': 'get_favorite_groups',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'n',
                    'offset',
                    'owner_id',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'n',
                    'offset',
                ]
            },
            root_map={
                'validations': {
                    ('n',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                    ('offset',): {

                        'inclusive_minimum': 0,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'n':
                        (int,),
                    'offset':
                        (int,),
                    'owner_id':
                        (str,),
                },
                'attribute_map': {
                    'n': 'n',
                    'offset': 'offset',
                    'owner_id': 'ownerId',
                },
                'location_map': {
                    'n': 'query',
                    'offset': 'query',
                    'owner_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_favorites_endpoint = _Endpoint(
            settings={
                'response_type': ([Favorite],),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/favorites',
                'operation_id': 'get_favorites',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'n',
                    'offset',
                    'type',
                    'tag',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'n',
                    'offset',
                ]
            },
            root_map={
                'validations': {
                    ('n',): {

                        'inclusive_maximum': 100,
                        'inclusive_minimum': 1,
                    },
                    ('offset',): {

                        'inclusive_minimum': 0,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'n':
                        (int,),
                    'offset':
                        (int,),
                    'type':
                        (str,),
                    'tag':
                        (str,),
                },
                'attribute_map': {
                    'n': 'n',
                    'offset': 'offset',
                    'type': 'type',
                    'tag': 'tag',
                },
                'location_map': {
                    'n': 'query',
                    'offset': 'query',
                    'type': 'query',
                    'tag': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.remove_favorite_endpoint = _Endpoint(
            settings={
                'response_type': (Success,),
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/favorites/{favoriteId}',
                'operation_id': 'remove_favorite',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'favorite_id',
                ],
                'required': [
                    'favorite_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'favorite_id':
                        (str,),
                },
                'attribute_map': {
                    'favorite_id': 'favoriteId',
                },
                'location_map': {
                    'favorite_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_favorite_group_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [
                    'apiKeyCookie',
                    'authCookie'
                ],
                'endpoint_path': '/favorite/group/{favoriteGroupType}/{favoriteGroupName}/{userId}',
                'operation_id': 'update_favorite_group',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'favorite_group_type',
                    'favorite_group_name',
                    'user_id',
                    'update_favorite_group_request',
                ],
                'required': [
                    'favorite_group_type',
                    'favorite_group_name',
                    'user_id',
                ],
                'nullable': [
                ],
                'enum': [
                    'favorite_group_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('favorite_group_type',): {

                        "WORLD": "world",
                        "FRIEND": "friend",
                        "AVATAR": "avatar"
                    },
                },
                'openapi_types': {
                    'favorite_group_type':
                        (str,),
                    'favorite_group_name':
                        (str,),
                    'user_id':
                        (str,),
                    'update_favorite_group_request':
                        (UpdateFavoriteGroupRequest,),
                },
                'attribute_map': {
                    'favorite_group_type': 'favoriteGroupType',
                    'favorite_group_name': 'favoriteGroupName',
                    'user_id': 'userId',
                },
                'location_map': {
                    'favorite_group_type': 'path',
                    'favorite_group_name': 'path',
                    'user_id': 'path',
                    'update_favorite_group_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def add_favorite(
        self,
        **kwargs
    ):
        """Add Favorite  # noqa: E501

        Add a new favorite.  Friend groups are named `group_0` through `group_3`. Avatar and World groups are named `avatars1` to `avatars4` and `worlds1` to `worlds4`.  You cannot add people whom you are not friends with to your friends list. Destroying a friendship removes the person as favorite on both sides.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.add_favorite(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            add_favorite_request (AddFavoriteRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Favorite
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.add_favorite_endpoint.call_with_http_info(**kwargs)

    def clear_favorite_group(
        self,
        favorite_group_type,
        favorite_group_name,
        user_id,
        **kwargs
    ):
        """Clear Favorite Group  # noqa: E501

        Clear ALL contents of a specific favorite group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.clear_favorite_group(favorite_group_type, favorite_group_name, user_id, async_req=True)
        >>> result = thread.get()

        Args:
            favorite_group_type (str): The type of group to fetch, must be a valid FavoriteType.
            favorite_group_name (str):
            user_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Success
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['favorite_group_type'] = \
            favorite_group_type
        kwargs['favorite_group_name'] = \
            favorite_group_name
        kwargs['user_id'] = \
            user_id
        return self.clear_favorite_group_endpoint.call_with_http_info(**kwargs)

    def get_favorite(
        self,
        favorite_id,
        **kwargs
    ):
        """Show Favorite  # noqa: E501

        Return information about a specific Favorite.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_favorite(favorite_id, async_req=True)
        >>> result = thread.get()

        Args:
            favorite_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Favorite
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['favorite_id'] = \
            favorite_id
        return self.get_favorite_endpoint.call_with_http_info(**kwargs)

    def get_favorite_group(
        self,
        favorite_group_type,
        favorite_group_name,
        user_id,
        **kwargs
    ):
        """Show Favorite Group  # noqa: E501

        Fetch information about a specific favorite group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_favorite_group(favorite_group_type, favorite_group_name, user_id, async_req=True)
        >>> result = thread.get()

        Args:
            favorite_group_type (str): The type of group to fetch, must be a valid FavoriteType.
            favorite_group_name (str):
            user_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            FavoriteGroup
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['favorite_group_type'] = \
            favorite_group_type
        kwargs['favorite_group_name'] = \
            favorite_group_name
        kwargs['user_id'] = \
            user_id
        return self.get_favorite_group_endpoint.call_with_http_info(**kwargs)

    def get_favorite_groups(
        self,
        **kwargs
    ):
        """List Favorite Groups  # noqa: E501

        Return a list of favorite groups owned by a user. Returns the same information as `getFavoriteGroups`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_favorite_groups(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            n (int): The number of objects to return.. [optional] if omitted the server will use the default value of 60
            offset (int): A zero-based offset from the default object sorting from where search results start.. [optional]
            owner_id (str): The owner of whoms favorite groups to return. Must be a UserID.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [FavoriteGroup]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_favorite_groups_endpoint.call_with_http_info(**kwargs)

    def get_favorites(
        self,
        **kwargs
    ):
        """List Favorites  # noqa: E501

        Returns a list of favorites.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_favorites(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            n (int): The number of objects to return.. [optional] if omitted the server will use the default value of 60
            offset (int): A zero-based offset from the default object sorting from where search results start.. [optional]
            type (str): The type of favorites to return, FavoriteType.. [optional]
            tag (str): Tags to include (comma-separated). Any of the tags needs to be present.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [Favorite]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_favorites_endpoint.call_with_http_info(**kwargs)

    def remove_favorite(
        self,
        favorite_id,
        **kwargs
    ):
        """Remove Favorite  # noqa: E501

        Remove a favorite from your favorites list.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.remove_favorite(favorite_id, async_req=True)
        >>> result = thread.get()

        Args:
            favorite_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Success
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['favorite_id'] = \
            favorite_id
        return self.remove_favorite_endpoint.call_with_http_info(**kwargs)

    def update_favorite_group(
        self,
        favorite_group_type,
        favorite_group_name,
        user_id,
        **kwargs
    ):
        """Update Favorite Group  # noqa: E501

        Update information about a specific favorite group.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_favorite_group(favorite_group_type, favorite_group_name, user_id, async_req=True)
        >>> result = thread.get()

        Args:
            favorite_group_type (str): The type of group to fetch, must be a valid FavoriteType.
            favorite_group_name (str):
            user_id (str):

        Keyword Args:
            update_favorite_group_request (UpdateFavoriteGroupRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['favorite_group_type'] = \
            favorite_group_type
        kwargs['favorite_group_name'] = \
            favorite_group_name
        kwargs['user_id'] = \
            user_id
        return self.update_favorite_group_endpoint.call_with_http_info(**kwargs)




# flake8: noqa

"""
    VRChat API Documentation


    The version of the OpenAPI document: 1.7.3
    Contact: me@ariesclark.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from vrchatapi.api_client import ApiClient

# import Configuration
from vrchatapi.configuration import Configuration

# import exceptions
from vrchatapi.exceptions import OpenApiException
from vrchatapi.exceptions import ApiAttributeError
from vrchatapi.exceptions import ApiTypeError
from vrchatapi.exceptions import ApiValueError
from vrchatapi.exceptions import ApiKeyError
from vrchatapi.exceptions import ApiException



"""
    VRChat API Documentation


    The version of the OpenAPI document: 1.7.3
    Contact: me@ariesclark.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from vrchatapi.api_client import ApiClient, Endpoint as _Endpoint
from vrchatapi.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from vrchatapi.model.api_config import APIConfig
from vrchatapi.model.api_health import APIHealth
from vrchatapi.model.error import Error
from vrchatapi.model.info_push import InfoPush


class SystemApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_config_endpoint = _Endpoint(
            settings={
                'response_type': (APIConfig,),
                'auth': [],
                'endpoint_path': '/config',
                'operation_id': 'get_config',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_css_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/css/app.css',
                'operation_id': 'get_css',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'variant',
                    'branch',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'variant',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('variant',): {

                        "PUBLIC": "public",
                        "INTERNAL": "internal"
                    },
                },
                'openapi_types': {
                    'variant':
                        (str,),
                    'branch':
                        (str,),
                },
                'attribute_map': {
                    'variant': 'variant',
                    'branch': 'branch',
                },
                'location_map': {
                    'variant': 'query',
                    'branch': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'text/css',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_current_online_users_endpoint = _Endpoint(
            settings={
                'response_type': (int,),
                'auth': [],
                'endpoint_path': '/visits',
                'operation_id': 'get_current_online_users',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_health_endpoint = _Endpoint(
            settings={
                'response_type': (APIHealth,),
                'auth': [],
                'endpoint_path': '/health',
                'operation_id': 'get_health',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_info_push_endpoint = _Endpoint(
            settings={
                'response_type': ([InfoPush],),
                'auth': [],
                'endpoint_path': '/infoPush',
                'operation_id': 'get_info_push',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'require',
                    'include',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'require':
                        (str,),
                    'include':
                        (str,),
                },
                'attribute_map': {
                    'require': 'require',
                    'include': 'include',
                },
                'location_map': {
                    'require': 'query',
                    'include': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_java_script_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/js/app.js',
                'operation_id': 'get_java_script',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'variant',
                    'branch',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'variant',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('variant',): {

                        "PUBLIC": "public",
                        "INTERNAL": "internal"
                    },
                },
                'openapi_types': {
                    'variant':
                        (str,),
                    'branch':
                        (str,),
                },
                'attribute_map': {
                    'variant': 'variant',
                    'branch': 'branch',
                },
                'location_map': {
                    'variant': 'query',
                    'branch': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/javascript',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_system_time_endpoint = _Endpoint(
            settings={
                'response_type': (datetime,),
                'auth': [],
                'endpoint_path': '/time',
                'operation_id': 'get_system_time',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def get_config(
        self,
        **kwargs
    ):
        """Fetch API Config  # noqa: E501

        API config contains configuration that the clients needs to work properly.  Currently the most important value here is `clientApiKey` which is used for all other API endpoints.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_config(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            APIConfig
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_config_endpoint.call_with_http_info(**kwargs)

    def get_css(
        self,
        **kwargs
    ):
        """Download CSS  # noqa: E501

        Fetches the CSS code to the frontend React website.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_css(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            variant (str): Specifies which `variant` of the site. Public is the end-user site, while `internal` is the staff-only site with special pages for moderation and management.. [optional] if omitted the server will use the default value of "public"
            branch (str): Specifies which git branch the site should load frontend source code from.. [optional] if omitted the server will use the default value of "main"
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_css_endpoint.call_with_http_info(**kwargs)

    def get_current_online_users(
        self,
        **kwargs
    ):
        """Current Online Users  # noqa: E501

        Returns the current number of online users.  **NOTE:** The response type is not a JSON object, but a simple JSON integer.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_current_online_users(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            int
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_current_online_users_endpoint.call_with_http_info(**kwargs)

    def get_health(
        self,
        **kwargs
    ):
        """Check API Health  # noqa: E501

        ~~Gets the overall health status, the server name, and the current build version tag of the API.~~  **DEPRECATED:** VRChat has suddenly restricted this endpoint for unknown reasons, and now always return 401 Unauthorized.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_health(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            APIHealth
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_health_endpoint.call_with_http_info(**kwargs)

    def get_info_push(
        self,
        **kwargs
    ):
        """Show Information Notices  # noqa: E501

        IPS (Info Push System) is a system for VRChat to push out dynamic information to the client. This is primarily used by the Quick-Menu info banners, but can also be used to e.g. alert you to update your game to the latest version.  `include` is used to query what Information Pushes should be included in the response. If include is missing or empty, then no notices will normally be returned. This is an \"any of\" search.  `require` is used to limit what Information Pushes should be included in the response. This is usually used in combination with `include`, and is an \"all of\" search.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_info_push(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            require (str): Tags to include (comma-separated). All of the tags needs to be present.. [optional]
            include (str): Tags to include (comma-separated). Any of the tags needs to be present.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [InfoPush]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_info_push_endpoint.call_with_http_info(**kwargs)

    def get_java_script(
        self,
        **kwargs
    ):
        """Download JavaScript  # noqa: E501

        Fetches the JavaScript code to the frontend React website.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_java_script(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            variant (str): Specifies which `variant` of the site. Public is the end-user site, while `internal` is the staff-only site with special pages for moderation and management.. [optional] if omitted the server will use the default value of "public"
            branch (str): Specifies which git branch the site should load frontend source code from.. [optional] if omitted the server will use the default value of "main"
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_java_script_endpoint.call_with_http_info(**kwargs)

    def get_system_time(
        self,
        **kwargs
    ):
        """Current System Time  # noqa: E501

        Returns the current time of the API server.  **NOTE:** The response type is not a JSON object, but a simple JSON string.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_system_time(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            datetime
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.get_system_time_endpoint.call_with_http_info(**kwargs)

